api.sensors.v1 package — Argus-Toolbelt 1.0 documentation

# api.sensors.v1 package

## Submodules

## api.sensors.v1.sensor module

Autogenerated API

`api.sensors.v1.sensor.` `find_sensors`(limit: int = None, offset: int = None, customerID: list = None, keywords: list = None, sortBy: list = None, startTimestamp: int = None, endTimestamp: int = None, includeFlags: list = None, excludeFlags: list = None, sensorID: list = None, locationName: list = None, applicationName: list = None, subCriteria: list = None, includeDeleted: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search sensors (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Limit results offset (int) – Offset results customerID (list) – Limit result to objects belonging to these customers keywords (list) – Search for sensors matching this hostname or IP-address sortBy (list) – Order results by these properties (prefix with - to sort descending) startTimestamp (int) – Search objects from this timestamp endTimestamp (int) – Search objects until this timestamp includeFlags (list) – Search objects with these flags set excludeFlags (list) – Exclude objects with these flags set sensorID (list) – Search for specific sensors by ID locationName (list) – Search for sensors bound to any of these locations applicationName (list) – Search for sensors by application type subCriteria (list) – includeDeleted (bool) – Also include deleted objects (where implemented)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 570, “limit”: 757, “responseCode”: 200, “count”: 153, “data”: [{“id”: 196, “expectedUpdateTime”: 809, “scheduledDowntimeFromTime”: 26, “scheduledDowntimeUntilTime”: 986, “information”: “Challenge soldier question relationship anything.”, “hostname”: “Bag crime court sport east.”, “additionalData”: “Attack general husband plant easy drug contain.”, “flags”: [“ACTIVE”], “lastUpdatedByUser”: {“id”: 239, “customerID”: 714, “userName”: “marcwillis”, “name”: “Vincent Wilson”}, “lastUpdatedTimestamp”: 1465277898, “lastAcknowledgedTimestamp”: 65587477, “inScheduledDowntime”: false}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Detail after pull like cultural president.”, “messageTemplate”: “White executive peace.”, “field”: “Note generation support order receive campaign dark.”, “parameter”: {}, “timestamp”: 1312697370}], “currentPage”: 539, “size”: 372}

`api.sensors.v1.sensor.` `get_sensor`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch sensor by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – ID of sensor to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 4, “limit”: 682, “responseCode”: 200, “count”: 492, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Together experience look exist peace.”, “messageTemplate”: “Can have two per on or past.”, “field”: “Analysis book evidence stay ready whole could.”, “parameter”: {}, “timestamp”: 1050950909}], “currentPage”: 943, “size”: 313}

`api.sensors.v1.sensor.` `get_sensor_comments`(sensorID: int, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch sensor comments by sensor ID (PUBLIC)

  Return type: | `dict`
  Parameters: | sensorID (int) – ID of sensor to fetch comments for limit (int) – Limit results offset (int) – Offset results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 468, “limit”: 90, “responseCode”: 200, “count”: 338, “data”: [{“timestamp”: 154081559, “user”: {“id”: 192, “customerID”: 11, “userName”: “michael94”, “name”: “Courtney Dominguez”}, “comment”: “Area ten bag view heart.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Truth bar less history treatment.”, “messageTemplate”: “Can statement glass note student hope them.”, “field”: “Suffer suggest record bit.”, “parameter”: {}, “timestamp”: 785537684}], “currentPage”: 689, “size”: 876}

`api.sensors.v1.sensor.` `list_sensors`(customerID: list = None, applicationName: list = None, keywords: list = None, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List sensors (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (list) – Limit search to these customer IDs applicationName (list) – Limit search to these applications by name keywords (list) – Limit search by sensor hostname or IP address limit (int) – Limit results offset (int) – Offset results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 233, “limit”: 538, “responseCode”: 200, “count”: 946, “data”: [{“id”: 385, “expectedUpdateTime”: 578, “scheduledDowntimeFromTime”: 894, “scheduledDowntimeUntilTime”: 918, “information”: “Another just three raise positive performance.”, “hostname”: “Color course protect number land could yet.”, “additionalData”: “Decide purpose hotel radio include.”, “flags”: [“CLOCK_OUT_OF_SYNC”], “lastUpdatedByUser”: {“id”: 791, “customerID”: 673, “userName”: “kelly80”, “name”: “Sharon Wallace”}, “lastUpdatedTimestamp”: 222753395, “lastAcknowledgedTimestamp”: 321492218, “inScheduledDowntime”: true}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Significant wear black move avoid democratic.”, “messageTemplate”: “Society forward either authority notice it than.”, “field”: “Owner seat market onto line media during model.”, “parameter”: {}, “timestamp”: 1116532982}], “currentPage”: 19, “size”: 832}

## api.sensors.v1.status module

Autogenerated API

`api.sensors.v1.status.` `find_sensors`(limit: int = None, offset: int = None, customerID: list = None, keywords: list = None, sortBy: list = None, startTimestamp: int = None, endTimestamp: int = None, includeFlags: list = None, excludeFlags: list = None, sensorID: list = None, locationName: list = None, applicationName: list = None, subCriteria: list = None, includeDeleted: bool = 'False', excludeReportingSensors: bool = 'False', excludeSensorsInScheduledDowntime: bool = 'False', excludeSensorsInReportingCluster: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search sensor status (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Limit results offset (int) – Offset results customerID (list) – Limit result to objects belonging to these customers keywords (list) – Search for sensors matching this hostname or IP-address sortBy (list) – Order results by these properties (prefix with - to sort descending) startTimestamp (int) – Search objects from this timestamp endTimestamp (int) – Search objects until this timestamp includeFlags (list) – Search objects with these flags set excludeFlags (list) – Exclude objects with these flags set sensorID (list) – Search for specific sensors by ID locationName (list) – Search for sensors bound to any of these locations applicationName (list) – Search for sensors by application type subCriteria (list) – includeDeleted (bool) – Also include deleted objects (where implemented) excludeReportingSensors (bool) – Exclude sensors which are reporting excludeSensorsInScheduledDowntime (bool) – Exclude sensors which are in scheduled downtime excludeSensorsInReportingCluster (bool) – Exclude sensors which are member of a cluster where any member is reporting
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 276, “limit”: 701, “responseCode”: 200, “count”: 757, “data”: [{“lastEventTimestamp”: 280776245, “lastUpdateTimestamp”: 1254576976, “messageRate”: 320, “lastAgentHost”: “Fine can hear because manager finish American.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Focus go six west.”, “messageTemplate”: “Recognize show hotel approach to.”, “field”: “Process sign both site right particular.”, “parameter”: {}, “timestamp”: 819592290}], “currentPage”: 664, “size”: 567}

`api.sensors.v1.status.` `get_sensor`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch sensor status by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – ID of sensor to fetch status for
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 284, “limit”: 930, “responseCode”: 200, “count”: 886, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Thousand list candidate wife.”, “messageTemplate”: “Staff like response bed choose dream main.”, “field”: “Free human positive condition.”, “parameter”: {}, “timestamp”: 863758244}], “currentPage”: 240, “size”: 790}

`api.sensors.v1.status.` `list_sensors`(customerID: list = None, applicationName: list = None, keywords: list = None, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List sensor status (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (list) – Limit search to these customer IDs applicationName (list) – Limit search to these applications by name keywords (list) – Limit search by sensor hostname or IP address offset (int) – Offset results limit (int) – Limit results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 243, “limit”: 553, “responseCode”: 200, “count”: 509, “data”: [{“lastEventTimestamp”: 40851747, “lastUpdateTimestamp”: 610509467, “messageRate”: 855, “lastAgentHost”: “Recently authority assume may carry financial process.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Remain right over stop.”, “messageTemplate”: “Would word part student final money.”, “field”: “Outside board pick or such wide.”, “parameter”: {}, “timestamp”: 83627310}], “currentPage”: 245, “size”: 961}

## Module contents